require 'spec_helper'
require 'data/snotel_api'

describe SnotelAPI do
  describe 'xml methods' do
    it 'has correct get_all_stations xml' do
      expected_xml = <<-eos.strip_heredoc
        <networkCds>SNTL</networkCds>
        <logicalAnd>true</logicalAnd>
      eos
      SnotelAPI.get_all_stations_xml.should == expected_xml
    end
    it 'has correct get_station_metadata xml' do
      station_triplet = '302:OR:SNTL'
      expected_xml = "<stationTriplet>#{station_triplet}</stationTriplet>"
      SnotelAPI.get_station_metadata_xml(station_triplet).should == expected_xml
    end
    it 'has correct get_bounded_stations xml' do
      min_lat = 0
      max_lat = 1
      min_lon = 2
      max_lon = 3
      expected_xml = <<-eos.strip_heredoc
        <networkCds>SNTL</networkCds>
        <minLatitude>#{min_lat}</minLatitude>
        <maxLatitude>#{max_lat}</maxLatitude>
        <minLongitude>#{min_lon}</minLongitude>
        <maxLongitude>#{max_lon}</maxLongitude>
        <logicalAnd>true</logicalAnd>
      eos
      SnotelAPI.get_bounded_stations_xml(min_lat, max_lat, min_lon, max_lon).should == expected_xml
    end
  end
  describe 'xml API methods' do
    it 'has working get_station_metadata' do
      VCR.use_cassette('data#get_station_metadata') do
        result = SnotelAPI.get_station_metadata('302:OR:SNTL')
        result[:county_name].should == 'WALLOWA'
        result[:fips_county_cd].should == '063'
        result[:station_triplet].should == '302:OR:SNTL'
      end
    end
    it 'has working get_all_stations' do
      VCR.use_cassette('data#get_all_stations') do
        SnotelAPI.get_all_stations()
      end
    end
    it 'has working get_bounded_stations' do
      VCR.use_cassette('data#get_bounded_stations') do
        stations = SnotelAPI.get_bounded_stations(41.234, 41.236, -120.792, -120.790)
        stations.should == ['301:CA:SNTL']
      end
    end
  end
end